Cosmological Analysis
---------------------

These scripts demonstrate some basic and more advanced analysis that can be
performed on cosmological simulation datasets.

Plotting Halos
~~~~~~~~~~~~~~

This is a mechanism for plotting circles representing identified particle halos
on an image.
See :ref:`halo-analysis` and :ref:`annotate-halos` for more information.

.. literalinclude:: halo_plotting.py

.. _cookbook-light_cone:

Light Cone Projection
~~~~~~~~~~~~~~~~~~~~~

This script creates a light cone projection, a synthetic observation
that stacks together projections from multiple datasets to extend over
a given redshift interval.
See :ref:`light-cone-generator` for more information.

.. literalinclude:: light_cone_projection.py

.. _cookbook-light_ray:
